#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import absolute_import
from __future__ import print_function
import lxml.sax
from lxml import etree
from six import StringIO
from .content_handler import XUpdateHandler

def applyXUpdate(xml_xu_file=None,
                 xml_doc_file=None,
                 xml_xu_string=None,
                 xml_doc_string=None,
                 xml_xu_filename=None,
                 xml_doc_filename=None):
  etree_parser = etree.XMLParser(remove_blank_text=True)
  if xml_xu_file:
    xml_xu = xml_xu_file
  if xml_xu_string:
    xml_xu = StringIO(xml_xu_string)
  if xml_xu_filename:
    xml_xu = xml_xu_filename
  if xml_doc_file:
    xml_doc = xml_doc_file
  if xml_doc_string:
    xml_doc = StringIO(xml_doc_string)
  if xml_doc_filename:
    xml_doc = xml_doc_filename
  original_tree = etree.parse(xml_doc, etree_parser)
  content_handler = XUpdateHandler(original_tree=original_tree)
  lxml.sax.saxify(etree.parse(xml_xu, etree_parser), content_handler)
  return content_handler.result_tree

if __name__ == '__main__':
  import sys
  doc_xml_name = sys.argv[1]
  xu_xml_name = sys.argv[2]
  print(etree.tostring(applyXUpdate(xml_xu_filename=xu_xml_name, xml_doc_filename=doc_xml_name), pretty_print=True))
